@@ -50,14 +50,16 @@ class Charge:
         return chg_sum
 
     def __sub__(self, other):
-        return self + (-1. * other)
+        return self + (-1.0 * other)
 
     def __mul__(self, other):
         return other * self
 
     def __rmul__(self, x):
         if not isinstance(x, (float, int, complex)):
-            raise ValueError("Charge instance can only be multiplied by a numerical scalar.")
+            raise ValueError(
+                "Charge instance can only be multiplied by a numerical scalar."
+            )
 
         res = Charge(self.poscar, x * self.tot_chg, [x * e for e in self.tot_aug])
 
@@ -69,9 +71,11 @@ class Charge:
 
     def __div__(self, x):
         if not isinstance(x, (float, int, complex)):
-            raise ValueError("Charge instance can only be divided by a numerical scalar.")
+            raise ValueError(
+                "Charge instance can only be divided by a numerical scalar."
+            )
 
-        return (1. / x) * self
+        return (1.0 / x) * self
 
     def total_only(self):
         if self.dif_part is None and self.dif_nc_part is None:
@@ -155,7 +159,7 @@ def read_block(file, shape):
     line = next(file)
     l1 = line.split()
 
-    nlines = ceil(npts / len(l1) - 1.)
+    nlines = ceil(npts / len(l1) - 1.0)
 
     # While this can seem a stupid way of writing this, it is actually
     # pretty fast because:
@@ -186,7 +190,7 @@ def write_block(file, data, fmt, stride):
 
     if bound < len(data):
         fmt = fmt * (len(data) - bound) + "\n"
-        file.write(fmt % tuple(data[bound:bound+stride]))
+        file.write(fmt % tuple(data[bound : bound + stride]))
 
 
 def prod(numbers):
