@@ -17,13 +17,13 @@ def read_forces(file):
             break
         nb_specs += 1
 
-    species = [
-        get_species(file)
-        for _ in range(nb_specs)
-    ]
+    species = [get_species(file) for _ in range(nb_specs)]
 
     nb_atoms = get_array(
-        file, "ions per type", expect_equal=True, map_=int,
+        file,
+        "ions per type",
+        expect_equal=True,
+        map_=int,
     )
 
     nb_tot = sum(nb_atoms)
@@ -35,9 +35,9 @@ def read_forces(file):
     assert tol is not None
 
     if tol > 0:
-        tol *= 10.
+        tol *= 10.0
     else:
-        tol *= -1.
+        tol *= -1.0
 
     raw = None
 
@@ -53,9 +53,6 @@ def read_forces(file):
     if raw is None:
         raise ValueError("Forces not found.")
 
-    forces = np.array([
-        line.split()[3:]
-        for line in raw
-    ], dtype=float)
+    forces = np.array([line.split()[3:] for line in raw], dtype=float)
 
     return list(zip(species, nb_atoms)), forces, tol
