@@ -27,7 +27,6 @@ class Batch:
         faulted = make_faulted_cell(sc)
         self.prepare_bundle(sc, faulted, name, bundle_name, encut, computations)
 
-
     def prepare_bundle(self, sc, faulted, name, bundle_name, encut, computations):
         d = ensure_abs_path(bundle_name)
         mkdir(d)
@@ -54,7 +53,9 @@ class Batch:
 
                 if sp:
                     # Shift to include Gamma
-                    kpoints -= min(kpoints, key=lambda v: np.linalg.norm(v)).reshape((1, 3))
+                    kpoints -= min(kpoints, key=lambda v: np.linalg.norm(v)).reshape(
+                        (1, 3)
+                    )
 
                 kpoints = np.fmod(kpoints + 0.5, 1.0) - 0.5
                 ibz = apply_symmetries(kpoints)
@@ -122,7 +123,6 @@ class Batch:
                             file=f,
                         )
 
-
     def makepot(self, struct, target):
         species = []
         pops = []
