@@ -3,16 +3,16 @@ import re
 
 def parse_tag(line):
     line_ = line
-    if '#' in line_:
-        line_, *_ = line_.split('#')
+    if "#" in line_:
+        line_, *_ = line_.split("#")
 
-    if '!' in line_:
-        line_, *_ = line_.split('!')
+    if "!" in line_:
+        line_, *_ = line_.split("!")
 
-    if '=' not in line_:
+    if "=" not in line_:
         return None
 
-    tag, val = [e.strip() for e in line_.split('=')]
+    tag, val = [e.strip() for e in line_.split("=")]
 
     return (tag, val)
 
