@@ -40,9 +40,7 @@ poscartool = MultiCmd(description=__doc__)
     optional(
         "--dest", "-o", type=str, default=None, help="Optional destination POSCAR"
     ),
-    flag(
-        "--direct", "-d", help="Write POSCAR in reduced coordinates."
-    ),
+    flag("--direct", "-d", help="Write POSCAR in reduced coordinates."),
 )
 def nudge(opts):
     from .forces import read_forces
@@ -59,7 +57,14 @@ def nudge(opts):
         dest = opts.poscar + ".nudge"
 
     with error_catch():
-        nudge(opts.poscar, dest, forces, A=opts.amplitude, rattle=opts.rattle, cartesian=opts.cartesian)
+        nudge(
+            opts.poscar,
+            dest,
+            forces,
+            A=opts.amplitude,
+            rattle=opts.rattle,
+            cartesian=opts.cartesian,
+        )
 
     return 0
 
