@@ -48,7 +48,4 @@ class Potcar:
 
 
 def predict_nelect(poscar, potcar):
-    return sum(
-        sp["valence"] * len(poscar.species[sp["name"]])
-        for sp in potcar.species
-    )
+    return sum(sp["valence"] * len(poscar.species[sp["name"]]) for sp in potcar.species)
